@@ -20,7 +20,7 @@ sub _build_base {
     my $base = $FindBin::Bin;
 
     while ( $base and not -e "$base/lib" ) {
-        $base =~ s:/[^/]+/?$::;
+        $base =~ s!/[^/]+/?$!!;
     }
 
     return $base;
@@ -29,10 +29,14 @@ sub _build_base {
 sub path {
     my ( $self, @path ) = @_;
     my ( $base ) = ( $self->base );
-
+    return $path[0]
+        if scalar @path eq 1    # if just one argument
+       and $path[0] =~ qr/^\//  # and appears absolute
+       and not -e "$base$path[0]" # and relative non-existence from the base
+       and -e $path[0]          # and absolute existence
+    ;
     @path = map { $_ =~ s/^\///; $_ =~ s/\/$//; $_ } @path;
     $base =~ s/\/$//;
-
     return join '/', $base, @path;
 }
 
@@ -92,7 +96,7 @@ Nour::Base - just a base role
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 NAME
 
